@@ -1,5 +1,6 @@
 from __future__ import annotations
 
+from typing import Any
 from typing import Optional
 from .publickey import PublicKey
 from .core.http import HTTPClient
@@ -28,45 +29,45 @@ class Client:
         self.http.refresh()
 
     def get_account_info(self, public_key: PublicKey | str) -> RPCResponse:
-        data = self.http.build_data(
+        data: dict[str, Any] = self.http.build_data(
             method="getAccountInfo", params=[public_key]
         )
-        res = self.http.send(data)
+        res: RPCResponse = self.http.send(data)
         return res
 
     def get_balance(self, public_key: PublicKey | str) -> RPCResponse:
-        data = self.http.build_data(
+        data: dict[str, Any] = self.http.build_data(
             method="getBalance", params=[public_key]
         )
-        res = self.http.send(data)
+        res: RPCResponse = self.http.send(data)
         return res
 
     def get_block(self, slot: int) -> RPCResponse:
-        data = self.http.build_data(
+        data: dict[str, Any] = self.http.build_data(
             method="getBlock", params=[slot]
         )
-        res = self.http.send(data)
+        res: RPCResponse = self.http.send(data)
         return res
 
     def get_block_height(self) -> RPCResponse:
-        data = self.http.build_data(
+        data: dict[str, Any] = self.http.build_data(
             method="getBlockHeight", params=[None]
         )
-        res = self.http.send(data)
+        res: RPCResponse = self.http.send(data)
         return res
 
     def get_block_production(self) -> RPCResponse:
-        data = self.http.build_data(
+        data: dict[str, Any] = self.http.build_data(
             method="getBlockProduction", params=[None]
         )
-        res = self.http.send(data)
+        res: RPCResponse = self.http.send(data)
         return res
 
     def get_block_commitment(self, block: int) -> RPCResponse:
-        data = self.http.build_data(
+        data: dict[str, Any] = self.http.build_data(
             method="getBlockCommitment", params=[block]
         )
-        res = self.http.send(data)
+        res: RPCResponse = self.http.send(data)
         return res
 
     def get_blocks(self, start_slot: int, end_slot: Optional[int] = None
@@ -75,105 +76,105 @@ class Client:
         if end_slot:
             params.append(end_slot)
 
-        data = self.http.build_data(
+        data: dict[str, Any] = self.http.build_data(
             method="getBlocks", params=params
         )
-        res = self.http.send(data)
+        res: RPCResponse = self.http.send(data)
         return res
 
     def get_blocks_with_limit(self, start_slot: int, limit: int
                               ) -> RPCResponse:
 
-        data = self.http.build_data(
+        data: dict[str, Any] = self.http.build_data(
             method="getBlocksWithLimit", params=[start_slot, limit]
         )
-        res = self.http.send(data)
+        res: RPCResponse = self.http.send(data)
         return res
 
     def get_block_time(self, block: int) -> RPCResponse:
 
-        data = self.http.build_data(
+        data: dict[str, Any] = self.http.build_data(
             method="getBlockTime", params=[block]
         )
-        res = self.http.send(data)
+        res: RPCResponse = self.http.send(data)
         return res
 
     def get_cluster_nodes(self) -> RPCResponse:
 
-        data = self.http.build_data(
+        data: dict[str, Any] = self.http.build_data(
             method="getClusterNodes", params=[None]
         )
-        res = self.http.send(data)
+        res: RPCResponse = self.http.send(data)
         return res
 
     def get_epoch_info(self) -> RPCResponse:
 
-        data = self.http.build_data(
+        data: dict[str, Any] = self.http.build_data(
             method="getEpochInfo", params=[None]
         )
-        res = self.http.send(data)
+        res: RPCResponse = self.http.send(data)
         return res
 
     def get_epoch_schedule(self) -> RPCResponse:
 
-        data = self.http.build_data(
+        data: dict[str, Any] = self.http.build_data(
             method="getEpochSchedule", params=[None]
         )
-        res = self.http.send(data)
+        res: RPCResponse = self.http.send(data)
         return res
 
     def get_fee_for_message(self, message: str) -> RPCResponse:
 
-        data = self.http.build_data(
+        data: dict[str, Any] = self.http.build_data(
             method="getFeeForMessage", params=[message]
         )
-        res = self.http.send(data)
+        res: RPCResponse = self.http.send(data)
         return res
 
     # Going to be deprecated
     def get_fees(self) -> RPCResponse:
 
-        data = self.http.build_data(
+        data: dict[str, Any] = self.http.build_data(
             method="getFees", params=[None]
         )
-        res = self.http.send(data)
+        res: RPCResponse = self.http.send(data)
         return res
 
     def get_first_available_block(self) -> RPCResponse:
 
-        data = self.http.build_data(
+        data: dict[str, Any] = self.http.build_data(
             method="getFirstAvailableBlock", params=[None]
         )
-        res = self.http.send(data)
+        res: RPCResponse = self.http.send(data)
         return res
 
     def get_supply(self) -> RPCResponse:
-        data = self.http.build_data(
+        data: dict[str, Any] = self.http.build_data(
             method="getSupply", params=[None]
         )
-        res = self.http.send(data)
+        res: RPCResponse = self.http.send(data)
         return res
 
     def get_identity(self) -> RPCResponse:
-        data = self.http.build_data(
+        data: dict[str, Any] = self.http.build_data(
             method="getIdentity", params=[None]
         )
-        res = self.http.send(data)
+        res: RPCResponse = self.http.send(data)
         return res
 
     def get_transaction(self, signature: str) -> RPCResponse:
-        data = self.http.build_data(
+        data: dict[str, Any] = self.http.build_data(
             method="getTransaction", params=[signature]
         )
-        res = self.http.send(data)
+        res: RPCResponse = self.http.send(data)
         return res
 
     # Will switch to getFeeForMessage (latest)
     def get_recent_blockhash(self) -> RPCResponse:
-        data = self.http.build_data(
+        data: dict[str, Any] = self.http.build_data(
             method="getRecentBlockhash", params=[None]
         )
-        res = self.http.send(data)
+        res: RPCResponse = self.http.send(data)
         return res
 
     def get_token_accounts_by_owner(self, public_key: str | PublicKey,
@@ -187,7 +188,7 @@ class Client:
         # Who doesn't like JSON?
         encoding = kwargs.get("encoding", "jsonParsed")
 
-        data = self.http.build_data(
+        data: dict[str, Any] = self.http.build_data(
             method="getTokenAccountsByOwner",
             params=[
                 str(public_key),
@@ -195,17 +196,17 @@ class Client:
                 {"encoding": encoding}
             ]
         )
-        res = self.http.send(data)
+        res: RPCResponse = self.http.send(data)
         return res
 
     def request_airdrop(self, public_key: PublicKey | str, lamports: int
                         ) -> RPCResponse:
 
-        data = self.http.build_data(
+        data: dict[str, Any] = self.http.build_data(
             method="requestAirdrop",
             params=[public_key, lamports]
         )
-        res = self.http.send(data)
+        res: RPCResponse = self.http.send(data)
         return res
 
     def send_transaction(self, transaction: Transaction,
@@ -219,9 +220,9 @@ class Client:
         transaction.recent_blockhash = recent_blockhash
         transaction.sign()
 
-        data = self.http.build_data(
+        data: dict[str, Any] = self.http.build_data(
             method="sendTransaction",
             params=[transaction.serialize(), {"encoding": "base64"}]
         )
-        res = self.http.send(data)
+        res: RPCResponse = self.http.send(data)
         return res
